==> gucharmap-2.26.2-x86_64-1.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf gnome-character-map )
( cd usr/bin ; ln -sf gucharmap gnome-character-map )
( cd usr/bin ; rm -rf charmap )
( cd usr/bin ; ln -sf gucharmap charmap )
( cd usr/lib ; rm -rf libgucharmap.so )
( cd usr/lib ; ln -sf libgucharmap.so.7.0.0 libgucharmap.so )
( cd usr/lib ; rm -rf libgucharmap.so.7 )
( cd usr/lib ; ln -sf libgucharmap.so.7.0.0 libgucharmap.so.7 )
( cd usr/share/gnome/help/gucharmap/ca/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/de/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/de/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/el/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/el/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fi/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fi/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fr/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fr/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ko/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ko/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/pt_BR/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/pt_BR/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )

==> gucharmap-2.28.2-x86_64-1.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf charmap )
( cd usr/bin ; ln -sf gucharmap charmap )
( cd usr/bin ; rm -rf gnome-character-map )
( cd usr/bin ; ln -sf gucharmap gnome-character-map )
( cd usr/lib64 ; rm -rf libgucharmap.so.7 )
( cd usr/lib64 ; ln -sf libgucharmap.so.7.0.0 libgucharmap.so.7 )
( cd usr/lib64 ; rm -rf libgucharmap.so )
( cd usr/lib64 ; ln -sf libgucharmap.so.7.0.0 libgucharmap.so )
( cd usr/share/gnome/help/gucharmap/de/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/de/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fi/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fi/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/en_GB/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ca/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ko/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ko/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/vi/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/fr/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/fr/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/ru/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/pt_BR/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/pt_BR/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/el/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/el/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/cs/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/cs/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; rm -rf gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; ln -sf ../../C/figures/gucharmap_start_window.png gucharmap_start_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; rm -rf gucharmap_window.png )
( cd usr/share/gnome/help/gucharmap/oc/figures ; ln -sf ../../C/figures/gucharmap_window.png gucharmap_window.png )
